==> cdk8s-plus-20-1.0.0-beta.1-sources.jar: org/cdk8s/plus20/Probe.java <==
package org.cdk8s.plus20;

/**
 * Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-20T20:33:53.597Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = org.cdk8s.plus20.$Module.class, fqn = "cdk8s-plus-20.Probe")
public abstract class Probe extends software.amazon.jsii.JsiiObject {

    protected Probe(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Probe(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Probe() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Defines a probe based on a command which is executed within the container.
     * <p>
     * @param command The command to execute. This parameter is required.
     * @param options Options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromCommand(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> command, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.CommandProbeOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromCommand", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { java.util.Objects.requireNonNull(command, "command is required"), options });
    }

    /**
     * Defines a probe based on a command which is executed within the container.
     * <p>
     * @param command The command to execute. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromCommand(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> command) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromCommand", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { java.util.Objects.requireNonNull(command, "command is required") });
    }

    /**
     * Defines a probe based on an HTTP GET request to the IP address of the container.
     * <p>
     * @param path The URL path to hit. This parameter is required.
     * @param options Options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromHttpGet(final @org.jetbrains.annotations.NotNull java.lang.String path, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.HttpGetProbeOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromHttpGet", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { java.util.Objects.requireNonNull(path, "path is required"), options });
    }

    /**
     * Defines a probe based on an HTTP GET request to the IP address of the container.
     * <p>
     * @param path The URL path to hit. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromHttpGet(final @org.jetbrains.annotations.NotNull java.lang.String path) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromHttpGet", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { java.util.Objects.requireNonNull(path, "path is required") });
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends org.cdk8s.plus20.Probe {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }
    }
}

==> cdk8s-plus-20-2.0.0-beta.1-sources.jar: org/cdk8s/plus20/Probe.java <==
package org.cdk8s.plus20;

/**
 * Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.57.0 (build f614666)", date = "2022-05-18T01:15:32.356Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = org.cdk8s.plus20.$Module.class, fqn = "cdk8s-plus-20.Probe")
public class Probe extends software.amazon.jsii.JsiiObject {

    protected Probe(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Probe(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Defines a probe based on a command which is executed within the container.
     * <p>
     * @param command The command to execute. This parameter is required.
     * @param options Options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromCommand(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> command, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.CommandProbeOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromCommand", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { java.util.Objects.requireNonNull(command, "command is required"), options });
    }

    /**
     * Defines a probe based on a command which is executed within the container.
     * <p>
     * @param command The command to execute. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromCommand(final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> command) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromCommand", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { java.util.Objects.requireNonNull(command, "command is required") });
    }

    /**
     * Defines a probe based on an HTTP GET request to the IP address of the container.
     * <p>
     * @param path The URL path to hit. This parameter is required.
     * @param options Options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromHttpGet(final @org.jetbrains.annotations.NotNull java.lang.String path, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.HttpGetProbeOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromHttpGet", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { java.util.Objects.requireNonNull(path, "path is required"), options });
    }

    /**
     * Defines a probe based on an HTTP GET request to the IP address of the container.
     * <p>
     * @param path The URL path to hit. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromHttpGet(final @org.jetbrains.annotations.NotNull java.lang.String path) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromHttpGet", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { java.util.Objects.requireNonNull(path, "path is required") });
    }

    /**
     * Defines a probe based opening a connection to a TCP socket on the container.
     * <p>
     * @param options Options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromTcpSocket(final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.TcpSocketProbeOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromTcpSocket", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class), new Object[] { options });
    }

    /**
     * Defines a probe based opening a connection to a TCP socket on the container.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.Probe fromTcpSocket() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.Probe.class, "fromTcpSocket", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.Probe.class));
    }
}
